package pdfWriter;

import com.lowagie.text.Document;
import com.lowagie.text.pdf.*;
import com.lowagie.text.*;
import java.io.FileOutputStream;
import java.io.FileInputStream;

/**
 * 
 * @author Michael Klemke
 *
 * Konvertiert ein Textfile in PDF. Als Eingabeparamter wird das 
 * Textfile ohne Suffix (.txt) erwartet.
 */
public class PDFCreator
{
	/**
	 * F&uuml;hrt die eigentliche Konvertierung durch.
	 * 
	 * @param inputFile Das Textfile.
	 * @param outputFile Das pdf-File.
	 */
	public void perform(String inputFile, String outputFile)
		throws java.io.IOException, com.lowagie.text.DocumentException
	{
		// Erzeugen des Document-Objektes.
		Document document = new Document(PageSize.A4, 72, 72, 72, 72);
		PdfWriter writer = PdfWriter.getInstance(document, 
			new FileOutputStream(outputFile));
		writer.setEncryption(PdfWriter.STRENGTH128BITS, "", "", 
			PdfWriter.AllowCopy | PdfWriter.AllowPrinting);
		initializeDocument(document, inputFile);
		document.open();

		// ffnen des Input-Streams zum Einlesen der Datei.
		FileInputStream fis = new FileInputStream(inputFile);
		byte[] inputData = new byte[1000];
		while (fis.read(inputData, 0, 1000) != -1)
		{
			document.add(new Phrase(new String(inputData)));
		} // while (fis.read(inputData, 0, 1000) != -1)
		document.newPage();

		document.close();
	} // public void perform(String, String)


	/**
	 * Initialisiert das PDF.
	 * 
	 * @param doc Das iText-Document-Objekt.
	 * @param headerText Der Text, der in der Kopfzeile angezeigt werden soll.
	 */
	private void initializeDocument(Document doc, String headerText)
		throws java.io.IOException
	{
		HeaderFooter header = new HeaderFooter(new Phrase(headerText), false);
		header.setBorder(Rectangle.BOTTOM);
		header.setBottom(50);
		header.setBorderColor(java.awt.Color.CYAN);
		HeaderFooter footer = new HeaderFooter(new Phrase("Seite: "), true);
		footer.setAlignment(HeaderFooter.ALIGN_CENTER);
		footer.setBorder(Rectangle.TOP);
		doc.setHeader(header);
		doc.setFooter(footer);
		try
		{
			Image waterImage = Image.getInstance("pics/Wasserzeichen.png");
			waterImage.setAlignment(Image.MIDDLE);
			Watermark watermark = new Watermark(waterImage, 108, 200);
			doc.add(watermark);
		}  // try
		catch(BadElementException bee)
		{
			bee.printStackTrace();
		} // try ... catch(BadElementException)
	} // private void generaterHeader()


	public static void main(String[] args)
		throws Exception
	{
		if (args.length != 1)
		{
			System.out.println ("Usage: java pdfWriter.PDFCreator filename[.txt]");
			System.exit(0);
		} // if (args.length != 1)
		PDFCreator pdf = new PDFCreator();
		pdf.perform(args[0] + ".txt", args[0] + ".pdf");
	} // public static void main(String[])
} // public class PDFCreator

